.. include:: abbreviation.txt
.. include:: project-links.txt

.. _overview-page:

==========
 Overview
==========

What is PyMetrology ?
---------------------

PyMetrology is an open source Python module which provides a |Python|_ ....

How is PyMetrology licensed ?
-----------------------------

PyMetrology is licensed under the `GPLv3 <https://www.gnu.org/licenses/quick-guide-gplv3.en.html>`_.

Going further with PyMetrology
------------------------------

The best way to know what you can do with PyMetrology, and to learn it, is to look at the examples:

 * :ref:`PyMetrology Reference Manual <reference-manual-page>`
 * :ref:`Bibliography <bibliography-page>`

Which platforms are supported by PyMetrology ?
----------------------------------------------

PyMetrology runs on Linux, Windows 64-bit and Mac OS X.

How to install PyMetrology ?
----------------------------

The procedure to install PyMetrology is described in the :ref:`Installation Manual <installation-page>`.

Which version of Python is required ?
-------------------------------------

PyMetrology requires Python 3 and the version 3.5 is recommended so as to benefit from the new *@* syntax
for units.
